@@ -1,28 +1,38 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::Role::Version::Sanitize;
-BEGIN {
-  $Dist::Zilla::Role::Version::Sanitize::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::Role::Version::Sanitize::VERSION = '0.001002';
-}
+
+our $VERSION = '0.002000';
 
 # ABSTRACT: Sanitize a version from a plugin
 
-use Moose::Role;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose::Role qw(has around);
 use Moose::Util::TypeConstraints qw(enum);
 
 
+
+
+
+
+
+
+
+
+
+
 sub _normalize_normal {
-  my ( $self, $orig ) = @_;
+  my ( undef, $orig ) = @_;
   require version;
   return version->parse($orig)->normal;
 }
 
 sub _normalize_normal_3 {
-  my ( $self, $orig ) = @_;
+  my ( undef, $orig ) = @_;
   require version;
   my $v = version->parse($orig)->normal;
   $v =~ s/\Av//msx;
@@ -57,6 +67,44 @@ sub _normalize_numify {
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 my %normal_forms = (
   normal   => '_normalize_normal',
   normal_3 => '_normalize_normal_3',
@@ -64,6 +112,13 @@ my %normal_forms = (
 );
 
 
+
+
+
+
+
+
+
 has normal_form => (
   is => ro =>,
   isa => enum( [ keys %normal_forms ] ),
@@ -73,6 +128,22 @@ has normal_form => (
 );
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 has mantissa => (
   is      => ro =>,
   isa     => 'Int',
@@ -107,6 +178,7 @@ around dump_config => sub {
 };
 
 no Moose::Role;
+no Moose::Util::TypeConstraints;
 
 1;
 
@@ -122,7 +194,7 @@ Dist::Zilla::Role::Version::Sanitize - Sanitize a version from a plugin
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
 =head1 ATTRIBUTES
 
@@ -200,7 +272,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
